package com.ynet.life.util;

import java.io.UnsupportedEncodingException;
import java.nio.charset.StandardCharsets;

/* loaded from: com_ynet_life_util.jar:com/ynet/life/util/Base64.class */
public final class Base64 {
    private static final int TWENTYFOURBITGROUP = 24;
    private static final int EIGHTBIT = 8;
    private static final int SIXTEENBIT = 16;
    private static final int SIXBIT = 6;
    private static final int FOURBYTE = 4;
    private static final int SIGN = -128;
    private static final byte PAD = 61;
    private static final int BASELENGTH = 255;
    private static byte[] base64Alphabet = new byte[BASELENGTH];
    private static final int LOOKUPLENGTH = 64;
    private static byte[] lookUpBase64Alphabet = new byte[LOOKUPLENGTH];

    static {
        for (int i = 0; i < BASELENGTH; i++) {
            base64Alphabet[i] = -1;
        }
        for (int i2 = 90; i2 >= 65; i2--) {
            int i3 = i2;
            base64Alphabet[i3] = (byte) (i3 - 65);
        }
        for (int i4 = 122; i4 >= 97; i4--) {
            int i5 = i4;
            base64Alphabet[i5] = (byte) ((i5 - 97) + 26);
        }
        for (int i6 = 57; i6 >= 48; i6--) {
            int i7 = i6;
            base64Alphabet[i7] = (byte) ((i7 - 48) + 52);
        }
        base64Alphabet[43] = 62;
        base64Alphabet[47] = 63;
        for (int i8 = 0; i8 <= 25; i8++) {
            lookUpBase64Alphabet[i8] = (byte) (i8 + 65);
        }
        int i9 = 26;
        int j = 0;
        while (i9 <= 51) {
            lookUpBase64Alphabet[i9] = (byte) (j + 97);
            i9++;
            j++;
        }
        int i10 = 52;
        int j2 = 0;
        while (i10 <= PAD) {
            lookUpBase64Alphabet[i10] = (byte) (j2 + 48);
            i10++;
            j2++;
        }
        lookUpBase64Alphabet[62] = 43;
        lookUpBase64Alphabet[63] = 47;
    }

    public static boolean isBase64(String isValidString) {
        return isArrayByteBase64(isValidString.getBytes());
    }

    public static boolean isBase64(byte octect) {
        return octect == PAD || base64Alphabet[octect] != -1;
    }

    public static boolean isArrayByteBase64(byte[] arrayOctect) {
        int length = arrayOctect.length;
        if (length == 0) {
            return true;
        }
        for (byte b : arrayOctect) {
            if (!isBase64(b)) {
                return false;
            }
        }
        return true;
    }

    public static String encode(String str) {
        if (str == null) {
            return "";
        }
        try {
            byte[] b = str.getBytes("UTF-8");
            return new String(encode(b), "UTF-8");
        } catch (UnsupportedEncodingException unused) {
            return "";
        }
    }

    public static String encodeToString(byte[] src) {
        byte[] encoded = encode(src);
        return new String(encoded, 0, 0, encoded.length);
    }

    public static byte[] encode(byte[] binaryData) {
        byte[] encodedData;
        byte b;
        byte b2;
        byte b3;
        byte b4;
        byte b5;
        int i;
        int lengthDataBits = binaryData.length << 3;
        int fewerThan24bits = lengthDataBits % TWENTYFOURBITGROUP;
        int numberTriplets = lengthDataBits / TWENTYFOURBITGROUP;
        if (fewerThan24bits != 0) {
            encodedData = new byte[(numberTriplets + 1) << 2];
        } else {
            encodedData = new byte[numberTriplets << 2];
        }
        int i2 = 0;
        while (i2 < numberTriplets) {
            int dataIndex = i2 * 3;
            byte b1 = binaryData[dataIndex];
            byte b22 = binaryData[dataIndex + 1];
            byte b32 = binaryData[dataIndex + 2];
            byte l = (byte) (b22 & 15);
            byte k = (byte) (b1 & 3);
            int encodedIndex = i2 << 2;
            if ((b1 & SIGN) == 0) {
                b4 = (byte) (b1 >> 2);
            } else {
                b4 = (byte) ((b1 >> 2) ^ 192);
            }
            byte b12 = b4;
            if ((b22 & SIGN) == 0) {
                b5 = (byte) (b22 >> FOURBYTE);
            } else {
                b5 = (byte) ((b22 >> FOURBYTE) ^ 240);
            }
            byte b23 = b5;
            if ((b32 & SIGN) == 0) {
                i = b32 >> SIXBIT;
            } else {
                i = (b32 >> SIXBIT) ^ 252;
            }
            byte val3 = (byte) i;
            encodedData[encodedIndex] = lookUpBase64Alphabet[b12];
            encodedData[encodedIndex + 1] = lookUpBase64Alphabet[b23 | (k << FOURBYTE)];
            encodedData[encodedIndex + 2] = lookUpBase64Alphabet[(l << 2) | val3];
            encodedData[encodedIndex + 3] = lookUpBase64Alphabet[b32 & 63];
            i2++;
        }
        int i3 = i2 * 3;
        int encodedIndex2 = i2 << 2;
        if (fewerThan24bits == EIGHTBIT) {
            byte b6 = binaryData[i3];
            byte k2 = (byte) (b6 & 3);
            if ((b6 & SIGN) == 0) {
                b3 = (byte) (b6 >> 2);
            } else {
                b3 = (byte) ((b6 >> 2) ^ 192);
            }
            byte val1 = b3;
            encodedData[encodedIndex2] = lookUpBase64Alphabet[val1];
            encodedData[encodedIndex2 + 1] = lookUpBase64Alphabet[k2 << FOURBYTE];
            encodedData[encodedIndex2 + 2] = PAD;
            encodedData[encodedIndex2 + 3] = PAD;
        } else if (fewerThan24bits == SIXTEENBIT) {
            byte b7 = binaryData[i3];
            byte b8 = binaryData[i3 + 1];
            byte l2 = (byte) (b8 & 15);
            byte k3 = (byte) (b7 & 3);
            if ((b7 & SIGN) == 0) {
                b = (byte) (b7 >> 2);
            } else {
                b = (byte) ((b7 >> 2) ^ 192);
            }
            byte val12 = b;
            if ((b8 & SIGN) == 0) {
                b2 = (byte) (b8 >> FOURBYTE);
            } else {
                b2 = (byte) ((b8 >> FOURBYTE) ^ 240);
            }
            byte val2 = b2;
            encodedData[encodedIndex2] = lookUpBase64Alphabet[val12];
            encodedData[encodedIndex2 + 1] = lookUpBase64Alphabet[val2 | (k3 << FOURBYTE)];
            encodedData[encodedIndex2 + 2] = lookUpBase64Alphabet[l2 << 2];
            encodedData[encodedIndex2 + 3] = PAD;
        }
        return encodedData;
    }

    public static String decode(String str) {
        if (str == null) {
            return "";
        }
        try {
            byte[] b = str.getBytes("UTF-8");
            return new String(decode(b), "UTF-8");
        } catch (UnsupportedEncodingException unused) {
            return "";
        }
    }

    public static byte[] decodeToByte(String src) {
        return decode(src.getBytes(StandardCharsets.ISO_8859_1));
    }

    public static byte[] decode(byte[] base64Data) {
        if (base64Data.length == 0) {
            return new byte[0];
        }
        int numberQuadruple = base64Data.length / FOURBYTE;
        int encodedIndex = 0;
        int lastData = base64Data.length;
        while (base64Data[lastData - 1] == PAD) {
            lastData--;
            if (lastData == 0) {
                return new byte[0];
            }
        }
        byte[] decodedData = new byte[lastData - numberQuadruple];
        for (int i = 0; i < numberQuadruple; i++) {
            int dataIndex = i << 2;
            byte marker0 = base64Data[dataIndex + 2];
            byte marker1 = base64Data[dataIndex + 3];
            byte b1 = base64Alphabet[base64Data[dataIndex]];
            byte b2 = base64Alphabet[base64Data[dataIndex + 1]];
            if (marker0 != PAD && marker1 != PAD) {
                byte b3 = base64Alphabet[marker0];
                byte b4 = base64Alphabet[marker1];
                decodedData[encodedIndex] = (byte) ((b1 << 2) | (b2 >> FOURBYTE));
                decodedData[encodedIndex + 1] = (byte) (((b2 & 15) << FOURBYTE) | ((b3 >> 2) & 15));
                decodedData[encodedIndex + 2] = (byte) ((b3 << SIXBIT) | b4);
            } else if (marker0 == PAD) {
                decodedData[encodedIndex] = (byte) ((b1 << 2) | (b2 >> FOURBYTE));
            } else if (marker1 == PAD) {
                byte b32 = base64Alphabet[marker0];
                decodedData[encodedIndex] = (byte) ((b1 << 2) | (b2 >> FOURBYTE));
                decodedData[encodedIndex + 1] = (byte) (((b2 & 15) << FOURBYTE) | ((b32 >> 2) & 15));
            }
            encodedIndex += 3;
        }
        return decodedData;
    }
}
